pub struct SignatureBlockFormat1<'a> {
data: FontData<'a>,
}Expand description
Fields
data: FontData<'a>Implementations
Sourceimpl<'a> SignatureBlockFormat1<'a>
impl<'a> SignatureBlockFormat1<'a>
pub const MIN_SIZE: usize
Sourcepub fn resolve_offset<O: Offset, R: FontRead<'a>>(
&self,
offset: O,
) -> Result<R, ReadError>
pub fn resolve_offset<O: Offset, R: FontRead<'a>>( &self, offset: O, ) -> Result<R, ReadError>
Resolve the provided offset from the start of this table.
Sourcepub fn offset_data(&self) -> FontData<'a>
pub fn offset_data(&self) -> FontData<'a>
Return a reference to this table’s raw data.
We use this in the compile crate to resolve offsets.
Sourcepub fn shape(&self) -> &Self
👎Deprecated: just use the base type directly
pub fn shape(&self) -> &Self
Return a reference to the table’s ‘Shape’ struct.
This is a low level implementation detail, but it can be useful in some cases where you want to know things about a table’s layout, such as the byte offsets of specific fields.
Sourcepub fn signature_length(&self) -> u32
pub fn signature_length(&self) -> u32
Length (in bytes) of the PKCS#7 packet in the signature field.
pub fn _reserved1_byte_range(&self) -> Range<usize> ⓘ
pub fn _reserved2_byte_range(&self) -> Range<usize> ⓘ
pub fn signature_length_byte_range(&self) -> Range<usize> ⓘ
pub fn signature_byte_range(&self) -> Range<usize> ⓘ
Sourceimpl SignatureBlockFormat1<'_>
impl SignatureBlockFormat1<'_>
Sourcefn compute_len(&self) -> usize
fn compute_len(&self) -> usize
Return the exact byte length of this table.